# LDBG JSON-RPC

Python3 Client SDK for Little Daemon Bot Gateway 
[jsonrpc-server-any](https://projectriri.github.io/bot-gateway/docs/Plugins.html#jsonrpc-server-any) Plugin.

## Install

```
pip3 install ldbg-jsonrpc
```

## Usage

Checkout [this](https://github.com/projectriri/bot-gateway/blob/master/adapters/jsonrpc-server-any/client/python/main.py) example.